@@ -1,4 +1,4 @@
-from datetime import datetime, timedelta
+from datetime import date, datetime, timedelta
 from unittest.mock import patch
 
 import pytest
@@ -56,7 +56,7 @@ def test_due_date(tmpdir, create, todos):
     todos = list(todos())
 
     assert len(todos) == 1
-    assert todos[0].due == datetime(2017, 6, 17, tzinfo=tzlocal())
+    assert todos[0].due == date(2017, 6, 17)
 
 
 def test_change_paths(tmpdir, create):
@@ -101,6 +101,27 @@ def test_list_colour(tmpdir):
     assert list_.colour == '#8ab6d2'
 
 
+def test_list_colour_cache_invalidation(tmpdir, sleep):
+    tmpdir.join('default').mkdir()
+    with tmpdir.join('default').join('color').open('w') as f:
+        f.write('#8ab6d2')
+
+    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite3'))
+    list_ = next(db.lists())
+
+    assert list_.colour == '#8ab6d2'
+
+    sleep()
+
+    with tmpdir.join('default').join('color').open('w') as f:
+        f.write('#f874fd')
+
+    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite3'))
+    list_ = next(db.lists())
+
+    assert list_.colour == '#f874fd'
+
+
 def test_list_no_colour(tmpdir):
     tmpdir.join('default').mkdir()
 
